@@ -11,7 +11,7 @@
 #'
 #' Only data.frame's are supported for now.
 #' @family bulk-functions
-#' @references <https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-bulk.html#bulk-update>
+#' @references <https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-bulk>
 #' @examples \dontrun{
 #' x <- connect()
 #' if (index_exists(x, "foobar")) index_delete(x, "foobar")
@@ -36,8 +36,8 @@
 #' Search(x, "foobar", asdf = TRUE)$hits$hits
 #' }
 docs_bulk_update <- function(conn, x, index = NULL, type = NULL,
-  chunk_size = 1000, doc_ids = NULL, raw = FALSE, quiet = FALSE, 
-  query = list(), digits = NA, ...) {
+  chunk_size = 1000, doc_ids = NULL, raw = FALSE, quiet = FALSE,
+  query = list(), digits = NA, sf = NULL, ...) {
 
   UseMethod("docs_bulk_update", x)
 }
@@ -45,7 +45,7 @@ docs_bulk_update <- function(conn, x, index = NULL, type = NULL,
 #' @export
 docs_bulk_update.default <- function(conn, x, index = NULL, type = NULL,
   chunk_size = 1000, doc_ids = NULL, raw = FALSE, quiet = FALSE,
-  query = list(), digits = NA, ...) {
+  query = list(), digits = NA, sf = NULL, ...) {
 
   stop("no 'docs_bulk_update' method for class ", class(x)[[1L]],
     call. = FALSE)
@@ -56,8 +56,8 @@ docs_bulk_update.data.frame <- make_bulk_df_generator(make_bulk_update)
 
 # helpers
 make_bulk_update <- function(df, index, counter, type = NULL, path = NULL,
-  digits = NA) {
-  
+  digits = NA, sf = NULL) {
+
   if (!is.character(counter)) {
     if (max(counter) >= 10000000000) {
       scipen <- getOption("scipen")
@@ -87,7 +87,7 @@ make_bulk_update <- function(df, index, counter, type = NULL, path = NULL,
   data <- lapply(seq_len(nrow(df)), function(i) {
     z <- list(doc = jsonlite::unbox(df[i,,drop=FALSE]), doc_as_upsert = TRUE)
     jsonlite::toJSON(z, auto_unbox = TRUE, na = "null", null = "null",
-      digits = digits)
+      digits = digits, sf = sf)
   })
 
   tmpf <- if (is.null(path)) tempfile("elastic__") else path
