@@ -4,7 +4,7 @@ x <- connect(port = Sys.getenv("TEST_ES_PORT"), warn = FALSE)
 load_shakespeare(x)
 
 test_that("cat_", {
-  if (!es_version(x) < 110) {
+  if (!x$es_ver() < 110) {
     a <- cat_(x, parse = TRUE)
     expect_is(a, "data.frame")
     expect_is(a$V1, "character")
@@ -14,16 +14,16 @@ test_that("cat_", {
 })
 
 test_that("cat_indices", {
-  if (!es_version(x) < 110) {
+  if (!x$es_ver() < 110) {
     b <- cat_indices(x, index = 'shakespeare', parse = TRUE, verbose = TRUE)
     c <- cat_indices(x, index = 'shakespeare', parse = TRUE, bytes = TRUE, verbose = TRUE)
     expect_is(b, "data.frame")
     expect_named(b)
-    
+
     expect_is(b$store.size, "character")
     expect_is(c$store.size, "integer")
-    
-    if (es_version(x) < 120) {
+
+    if (x$es_ver() < 120) {
       expect_message(cat_indices(x, index = "adf"), "Nothing to print")
     } else {
       expect_error(cat_indices(x, index = "adf"), "no such index||IndexMissing")
