@@ -21,16 +21,5 @@ test_that("count", {
   expect_gt(b, 10)
 
   expect_error(count(x, "adfadf"), "no such index||IndexMissing")
-  
-  if (x$es_ver() > 246) {
-    expect_equal(suppressWarnings(count(x, type = "adfad")), 0)
-  } else {
-    expect_error(count(x, type = "adfad"), 
-      "no such index||IndexMissingException")
-  }
 
-  if (z$es_ver() >= 700) {
-    expect_warning(count(z, 'shakespeare', type = "line"), 
-      "Specifying types in count requests is deprecated")
-  }
 })
