@@ -57,7 +57,7 @@ test_that("docs_create works with automatically created document IDs", {
     expect_error(docs_create(x, index = ind11,
       body = list(id = "12345", title = "Some title")),
       "'type' is required")
-  } else if (x$es_ver() < 700) { 
+  } else if (x$es_ver() < 700) {
     invisible(z<-docs_create(x, index = ind11, type = ind11,
       body = list(id = "12345", title = "Some title")))
     a <- docs_get(x, index = ind11, type = ind11, id = z$`_id`, verbose = FALSE)
@@ -75,7 +75,7 @@ test_that("docs_create works with automatically created document IDs", {
 })
 
 test_that("docs_create fails as expected", {
-  if (es_version(x) < 600) {
+  if (x$es_ver() < 600) {
     expect_error(docs_create(x, "adfadf"),
       "type' is required")
     expect_error(docs_create(x, "adfadf", type = "asdf"),
@@ -131,10 +131,10 @@ invisible(index_create(x, index = ind3, verbose = FALSE))
 
 test_that("docs_mget works", {
 
-  invisible(docs_create(x, index = ind3, type = "holla", id = 1, body = '{"hello": "world"}'))
-  invisible(docs_create(x, index = ind3, type = "holla", id = 2, body = '{"foo": "bar"}'))
-  invisible(docs_create(x, index = ind3, type = "holla", id = 3, body = '{"tables": "chairs"}'))
-  e <- docs_mget(x, index = ind3, type = "holla", ids = 1:3, verbose = FALSE)
+  invisible(docs_create(x, index = ind3, id = 1, body = '{"hello": "world"}'))
+  invisible(docs_create(x, index = ind3, id = 2, body = '{"foo": "bar"}'))
+  invisible(docs_create(x, index = ind3, id = 3, body = '{"tables": "chairs"}'))
+  e <- docs_mget(x, index = ind3, ids = 1:3, verbose = FALSE)
   expect_is(e, "list")
   expect_named(e, "docs")
   expect_is(e$docs, "list")
@@ -144,16 +144,16 @@ test_that("docs_mget works", {
 
 test_that("docs_delete works", {
 
-  f <- docs_delete(x, index = ind3, type = "holla", id = 3)
+  f <- docs_delete(x, index = ind3, id = 3)
   expect_is(f, "list")
-  if (es_version(x) < 600) {
+  if (x$es_ver() < 600) {
     expect_true(f$found)
   } else {
     expect_true("_seq_no" %in% names(f))
     expect_true("_primary_term" %in% names(f))
   }
   # error if try again to delete since document is gone
-  expect_error(docs_delete(x, index = ind3, type = "holla", id = 3), "Not Found")
+  expect_error(docs_delete(x, index = ind3, id = 3), "Not Found")
 })
 
 
@@ -169,21 +169,21 @@ invisible(index_create(x, index = ind5, verbose = FALSE))
 test_that("document ids with spaces work", {
 
   # create
-  f <- docs_create(x, index = ind4, type = ind4, id = "hello world", body = list(a = "asdfasdf"))
-  invisible(docs_create(x, index = ind4, type = ind4, id = "foo bar", body = list(a = "asdfadfadfasdfasdfsdf")))
-  if (es_version(x) < 600) {
+  f <- docs_create(x, index = ind4, id = "hello world", body = list(a = "asdfasdf"))
+  invisible(docs_create(x, index = ind4, id = "foo bar", body = list(a = "asdfadfadfasdfasdfsdf")))
+  if (x$es_ver() < 600) {
     invisible(docs_create(x, index = ind4, type = "dattype", id = "what the", body = list(a = "cars")))
   }
   expect_is(f, "list")
   expect_equal(f$`_id`, "hello world")
 
   # get
-  g <- docs_get(x, index = ind4, type = ind4, id = "hello world", verbose = FALSE)
+  g <- docs_get(x, index = ind4, id = "hello world", verbose = FALSE)
   expect_is(g, "list")
   expect_true(g$found)
 
   # mget - ids param
-  h <- docs_mget(x, index = ind4, type = ind4, ids = c("hello world", "foo bar"), verbose = FALSE)
+  h <- docs_mget(x, index = ind4, ids = c("hello world", "foo bar"), verbose = FALSE)
   expect_is(h, "list")
   expect_equal(length(h$docs), 2)
   expect_true(all(vapply(h$docs, "[[", logical(1), "found")))
@@ -192,16 +192,16 @@ test_that("document ids with spaces work", {
   hh <- docs_mget(x, index = ind4, type_id = list(c(ind4, "hello world"), c("dattype", "what the")), verbose = FALSE)
   expect_is(hh, "list")
   expect_equal(length(hh$docs), 2)
-  if (es_version(x) < 600) {
+  if (x$es_ver() < 600) {
     expect_true(all(vapply(hh$docs, "[[", logical(1), "found")))
   } else {
     expect_equal(vapply(hh$docs, "[[", logical(1), "found"), c(TRUE, FALSE))
   }
 
   # mget - index_type_id param
-  invisible(docs_create(x, index = ind5, type = ind5, id = "hello mars", body = list(radius = 1000000L)))
+  invisible(docs_create(x, index = ind5, id = "hello mars", body = list(radius = 1000000L)))
 
-  if (es_version(x) < 600) {
+  if (x$es_ver() < 600) {
 
     hhh <- docs_mget(x, index_type_id = list(
       c(ind4, ind4, "hello world"),
@@ -212,11 +212,11 @@ test_that("document ids with spaces work", {
     expect_true(all(vapply(hhh$docs, "[[", logical(1), "found")))
 
     # update
-    i <- docs_update(x, index = ind4, type = ind4, id = "hello world", body = list(doc = list(a = "an update")))
+    i <- docs_update(x, index = ind4, id = "hello world", body = list(doc = list(a = "an update")))
     expect_is(i, "list")
 
     # delete
-    j <- docs_delete(x, index = ind4, type = ind4, id = "hello world")
+    j <- docs_delete(x, index = ind4, id = "hello world")
     expect_is(j, "list")
     expect_true(j$found)
   }
