@@ -97,7 +97,7 @@ test_that("docs_bulk_update - works with data.frame input", {
 
   expect_is(a, "list")
   expect_equal(length(a), 1)
-  expect_named(a[[1]], c('took', 'errors', 'items'))
+  expect_named(a[[1]], c('took', 'errors', 'items'), ignore.order = TRUE)
   expect_equal(length(a[[1]]$items), NROW(iris))
 
   expect_is(res_before, "list")
@@ -122,17 +122,17 @@ test_that("docs_bulk_update - works with data.frame where ids are factors", {
   }
 
   df <- data.frame(name = letters[1:3], size = 1:3, id =c("AB", "CD", "EF"))
-  invisible(docs_bulk(x ,df, index = "mars", type = "mars", quiet = TRUE, es_ids = FALSE))
+  invisible(docs_bulk(x ,df, index = "mars", quiet = TRUE, es_ids = FALSE))
   # alter data.frame
   df$name <- letters[4:6]
   # update data
-  a <- docs_bulk_update(x, df, index = "mars", type = "mars", quiet = TRUE)
+  a <- docs_bulk_update(x, df, index = "mars", quiet = TRUE)
   Sys.sleep(1)
 
   expect_is(df$id, "character")
   expect_is(a, "list")
   expect_equal(length(a), 1)
-  expect_named(a[[1]], c('took', 'errors', 'items'))
+  expect_named(a[[1]], c('took', 'errors', 'items'), ignore.order = TRUE)
   expect_equal(length(a[[1]]$items), NROW(df))
   expect_equal(
     sort(Search(x, 'mars', asdf = TRUE)$hits$hits$`_id`),
@@ -183,7 +183,7 @@ test_that("docs_bulk_update - works with data.frame with boolean types", {
 
   # # toggle mapping types based on ES version
   # mixed_mapping <- if (x$es_ver() < 500) {
-  #   mixed_mapping_lt_v5 
+  #   mixed_mapping_lt_v5
   # } else if (x$es_ver() >= 700) {
   #   mixed_mapping_lt_v7
   # } else {
@@ -220,7 +220,7 @@ test_that("docs_bulk_update - works with data.frame with boolean types", {
   # ensure bulk update succeeded
   expect_is(update_res, "list")
   expect_equal(length(update_res), 1)
-  expect_named(update_res[[1]], c('took', 'errors', 'items'))
+  expect_named(update_res[[1]], c('took', 'errors', 'items'), ignore.order = TRUE)
   expect_equal(length(update_res[[1]]$items), nrow(mixed))
 
   # ensure search result types and values match original
@@ -248,8 +248,8 @@ test_that("docs_bulk_update cleans up temp files", {
   }
 
   df <- data.frame(name = letters[1:3], size = 1:3, id = 100:102)
-  invisible(docs_bulk(x ,df, "googoo", "googoo", quiet = TRUE, es_ids = FALSE))
-  aa <- docs_bulk_update(x, df, index="googoo", type="googoo",
+  invisible(docs_bulk(x ,df, "googoo", quiet = TRUE, es_ids = FALSE))
+  aa <- docs_bulk_update(x, df, index = "googoo",
     quiet = TRUE)
 
   expect_equal(length(list.files(curr_tempdir, pattern = "elastic__")), 0)
@@ -264,12 +264,12 @@ test_that("docs_bulk_update: suppressing progress bar works", {
   }
 
   df <- data.frame(name = letters[1:3], size = 1:3, id = 100:102)
-  invisible(docs_bulk(x, df, z, z, quiet = TRUE, es_ids = FALSE))
+  invisible(docs_bulk(x, df, z, quiet = TRUE, es_ids = FALSE))
 
   quiet_true <- capture.output(invisible(
-    docs_bulk_update(x, df, index=z, type=z, quiet = TRUE)))
+    docs_bulk_update(x, df, index = z, quiet = TRUE)))
   quiet_false <- capture.output(invisible(
-    docs_bulk_update(x, df, index=z, type=z, quiet = FALSE)))
+    docs_bulk_update(x, df, index = z, quiet = FALSE)))
   expect_equal(length(quiet_true), 0)
   expect_match(quiet_false, "=====")
 })
