@@ -46,7 +46,7 @@ bodysim <- '{
 }'
 
 test_that("pipeline_create", {
-  if (!es_version(x) < 500) {
+  if (!x$es_ver() < 500) {
     a <- pipeline_create(x, id = 'foo', body = body1)
     expect_true(a[[1]])
     expect_named(a, "acknowledged")
@@ -55,12 +55,12 @@ test_that("pipeline_create", {
     b <- pipeline_create(x, id = 'bar', body = body2)
     expect_true(b[[1]])
     expect_named(b, "acknowledged")
-    expect_is(b, "list")    
+    expect_is(b, "list")
   }
 })
 
 test_that("pipeline_get", {
-  if (!es_version(x) < 500) {
+  if (!x$es_ver() < 500) {
     # invisible(pipeline_create(x, id = 'foo', body = body1))
 
     a <- pipeline_get(x, "foo")
@@ -68,8 +68,8 @@ test_that("pipeline_get", {
     expect_is(a, "list")
     expect_is(a$foo, "list")
     expect_equal(a$foo$description, "do a thing")
-    
-    # can get multiple ids at once  
+
+    # can get multiple ids at once
     # invisible(pipeline_create(x, id = 'bar', body = body2))
 
     b <- pipeline_get(x, c("foo", "bar"))
@@ -78,7 +78,7 @@ test_that("pipeline_get", {
 })
 
 test_that("pipeline_delete", {
-  if (!es_version(x) < 500) {
+  if (!x$es_ver() < 500) {
     a <- pipeline_delete(x, 'foo')
     expect_named(a, "acknowledged")
     expect_is(a, "list")
@@ -89,7 +89,7 @@ test_that("pipeline_delete", {
 })
 
 test_that("pipeline_simulate", {
-  if (!es_version(x) < 500) {
+  if (!x$es_ver() < 500) {
     a <- pipeline_simulate(x, bodysim)
     expect_named(a, "docs")
     expect_is(a, "list")
@@ -100,14 +100,14 @@ test_that("pipeline_simulate", {
 })
 
 test_that("pipeline fxns error well", {
-  if (es_version(x) < 500) {
+  if (x$es_ver() < 500) {
     expect_error(pipeline_get(x, ""), "available in ES v5 and greater")
     expect_error(pipeline_create(x, "", ""), "available in ES v5 and greater")
     expect_error(pipeline_delete(x, "", ""), "available in ES v5 and greater")
     expect_error(pipeline_simulate(x, ""), "available in ES v5 and greater")
   }
 
-  if (!es_version(x) < 500) {
+  if (!x$es_ver() < 500) {
     expect_error(pipeline_get(x, ), "argument \"id\" is missing")
     expect_error(pipeline_create(x, ), "argument \"body\" is missing")
     expect_error(pipeline_delete(x, ), "argument \"id\" is missing")
@@ -116,6 +116,6 @@ test_that("pipeline fxns error well", {
 })
 
 ## cleanup -----------------------------------
-# if (!es_version(x) < 502) {
+# if (!x$es_ver() < 502) {
 #   invisible(pipeline_delete(x, "*"))
 # }
