@@ -1,6 +1,6 @@
 context("ping")
 
-x <- connect()
+x <- connect(port = Sys.getenv("TEST_ES_PORT"))
 
 test_that("ping", {
   expect_is(x$ping(), "list")
