@@ -5,8 +5,9 @@ z <- connect(port = Sys.getenv("TEST_ES_PORT"), warn = TRUE)
 
 test_that("validate", {
   if (!index_exists(x, "twitter")) index_create(x, "twitter")
-  docs_create(x, 'twitter', type='tweet', id=1, body = list(
-     "user" = "foobar", 
+
+  docs_create(x, 'twitter', id = 1, body = list(
+     "user" = "foobar",
      "post_date" = "2014-01-03",
      "message" = "trying out Elasticsearch"
    )
@@ -16,10 +17,10 @@ test_that("validate", {
   expect_is(a, "list")
   expect_equal(sort(names(a)), c('_shards', 'valid'))
   expect_true(a$valid)
-  
-  if (z$es_ver() >= 700) {
+
+  if (z$es_ver() >= 700 & x$es_ver() < 800) {
     expect_warning(
-      validate(z, "twitter", "tweet", q='user:foobar'),
+      validate(z, "twitter", "tweet", q = 'user:foobar'),
       "Specifying types in validate query requests is deprecated"
     )
   }
